Branch Manager for GitHub
=========================

This tool manages branch permissions for GitHub repositories. The goal is to
ensure that branches of repositories in your organisation are appropriately
protected by controlling their status only via the API, rather than manually
configuring the branch status.

Right now this tool is in an early alpha.
